;; Generated package description from fsm.el  -*- no-byte-compile: t -*-
(define-package "fsm" "0.2.1.0.20201129.120009" "state machine library" '((emacs "24.1") (cl-lib "0.5")) :url "https://elpa.gnu.org/packages/fsm.html" :authors '(("Magnus Henoch" . "magnus.henoch@gmail.com")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("extensions"))
